@@ -1,6 +1,9 @@
 from threading import Lock
 
+from requests import HTTPError
+
 from py42._internal.compat import str
+from py42.exceptions import Py42StorageSessionInitializationError
 
 
 class StorageSessionManager(object):
@@ -22,9 +25,9 @@ class StorageSessionManager(object):
                     if session is None:
                         session = self.create_storage_session(url, token_provider)
                         self._session_cache.update({url.lower(): session})
-        except Exception as ex:
+        except HTTPError as ex:
             message = u"Failed to create or retrieve session, caused by: {0}".format(str(ex))
-            raise Exception(message)
+            raise Py42StorageSessionInitializationError(message)
         return session
 
     def create_storage_session(self, url, token_provider):
